<?php
$translations = array(
	'General_Locale' => 'nn_NO.UTF-8',
	'General_TranslatorName' => 'Kristoffer Egil Bonarjee,Simon Hansen',
	'General_TranslatorEmail' => 'kristoffer.egil@bonarjee.in,simonboba@gmail.com',
	'General_EnglishLanguageName' => 'Norwegian Nynorsk',
	'General_OriginalLanguageName' => 'Nynorsk',
	'General_HelloUser' => 'Hallo %s!',
	'General_OpenSourceWebAnalytics' => 'Open Kjeldekode Nettanalyse',
	'General_Dashboard' => 'Dashbord',
	'General_DashboardForASpecificWebsite' => 'Dashbord for ein spesifikk nettstad',
	'General_MultiSitesSummary' => 'Alle nettstadar',
	'General_AllWebsitesDashboard' => 'Dashbord for alle nettstadar',
	'General_API' => 'API',
	'General_Settings' => 'Innstillingar',
	'General_GiveUsYourFeedback' => 'Gje oss attendemelding!',
	'General_Unknown' => 'Ukjent',
	'General_Required' => '%s krevjast',
	'General_NotValid' => '%s er ugyldig',
	'General_Error' => 'Feil',
	'General_Warning' => 'Åtvaring',
	'General_BackToHomepage' => 'Tilbake til Piwik si hovudside',
	'General_Yes' => 'Ja',
	'General_No' => 'Nei',
	'General_Delete' => 'Slett',
	'General_Edit' => 'Endre',
	'General_Ok' => 'Ok',
	'General_Close' => 'Lukk',
	'General_OrCancel' => 'eller %s Avbryt %s',
	'General_Logout' => 'Logg ut',
	'General_Username' => 'Brukarnamn',
	'General_Done' => 'Ferdig',
	'General_Name' => 'Namn',
	'General_Value' => 'Verdi',
	'General_Details' => 'Detaljar',
	'General_Default' => 'Standard',
	'General_Date' => 'Dato',
	'General_Period' => 'Periode',
	'General_Today' => 'Idag',
	'General_Yesterday' => 'Igår',
	'General_CurrentWeek' => 'Denne veka',
	'General_CurrentMonth' => 'Denne månaden',
	'General_CurrentYear' => 'Dette året',
	'General_DateRange' => 'Tidsperiode',
	'General_LoadingData' => 'Lastar data...',
	'General_Loading_js' => 'Lastar...',
	'General_GoTo' => 'Gå til %s',
	'General_Next' => 'Neste',
	'General_Previous' => 'Førre',
	'General_Search' => 'Søk',
	'General_Others' => 'Andre',
	'General_Table' => 'Tabell',
	'General_Piechart' => 'Kakestykke',
	'General_TagCloud' => 'Taggsky',
	'General_VBarGraph' => 'Søylediagram',
	'General_SaveImageOnYourComputer_js' => 'For å lagra biletet på maskina di, høgreklikk på biletet og vel "Lagre biletet som..."',
	'General_Refresh' => 'Frisk opp siden',
	'General_Visitors' => 'Vitjarar',
	'General_ExportAsImage_js' => 'Eksporter som bilete',
	'General_Export' => 'Eksporter',
	'General_YourChangesHaveBeenSaved' => 'Endringane dine er lagra.',
	'General_ErrorRequest' => 'Oops… det skjedde eit problem under spørjinga, prøv att.',
	'General_ColumnNbUniqVisitors' => 'Unike vitjarar',
	'General_ColumnNbVisits' => 'Vitjingar',
	'General_ColumnPercentageVisits' => '% Vitjingar',
	'General_ColumnNbActions' => 'Handlingar',
	'General_ColumnMaxActions' => 'Flest handlingar på ei vitjing',
	'General_ColumnSumVisitLength' => 'Total tid brukt av vitjarar (i sekund)',
	'General_ColumnLabel' => 'Etikett',
	'General_ColumnActionsPerVisit' => 'Handlingar per Vitjing',
	'General_VisitDuration' => 'Gjen. vitjingslengde (i sekund)',
	'General_ColumnAvgTimeOnSite' => 'Gjen. tid på nettstaden',
	'General_ColumnBounceRate' => 'Hopprate',
	'General_ColumnPageviews' => 'Sidevisingar',
	'General_ColumnUniquePageviews' => 'Unike sidevisingar',
	'General_ColumnBounces' => 'Hopp',
	'General_ColumnEntrances' => 'Inngangar',
	'General_ColumnExits' => 'Utgangar',
	'General_ColumnAverageTimeOnPage' => 'Gjen. tid på sida',
	'General_ColumnValuePerVisit' => 'Verdi per vising',
	'General_ColumnVisitsWithConversions' => 'Vitjingar med overgang',
	'General_MinutesSeconds' => '%1$s min %2$ss',
	'General_Seconds' => '%ss',
	'General_Save' => 'Lagre',
	'General_ForExampleShort' => 'td.',
	'General_Website' => 'Nettstad',
	'General_GeneralSettings' => 'Generelle innstillingar',
	'General_AllowPiwikArchivingToTriggerBrowser' => 'Godkjend at Piwik kan starta arkivering når rapporter blir vist i nettlesaren',
	'General_ArchivingInlineHelp' => 'For nettstader med medium til høg trafikk, er det tilrådd å slå av arkivering via nettlesaren. Me anbefaler heller at du sett opp ein cronjobb for å prosessera Piwik sine rapporter kvar time.',
	'General_ArchivingTriggerDescription' => 'For større installasjonar av Piwik er det tilrådd at du %ssett opp ein cron-jobb%s for å prosessera rapportane automatisk.',
	'General_SeeTheOfficialDocumentationForMoreInformation' => 'Sjå den %soffisielle dokumentasjonen%s for meir informasjon.',
	'General_NSeconds' => '%s sekund.',
	'General_SmallTrafficYouCanLeaveDefault' => 'For små nettstader kan du nytta dei vanlege %s sekundane, og sjå alle rapportane i sanntid.',
	'General_MediumToHighTrafficItIsRecommendedTo' => 'For nettstader med medium til høg trafikk, tilrår me å prosessera dagens rapport maksimalt kvar halve (%s sekundar) eller heile time (%s sekundar).',
	'General_RequiresFlash' => 'Grafar i Piwik krev Flash',
	'General_GraphHelp' => 'Meir informasjon om visning av grafar i Piwik.',
	'General_NoDataForGraph' => 'Inga data for denne grafen',
	'General_NoDataForTagCloud' => 'Inga data for denne taggskyen',
	'General_PiwikIsACollaborativeProjectYouCanContribute' => '%1$s Piwik %2$s er eit samarbeidsprosjekt. %3$s Om du likar Piwik, kan du hjelpa til! Sjekk ut %4$s Korleis delta i Piwik?%5$s',
	'General_YouAreViewingDemoShortMessage' => 'Du ser nett no på ein demo av Piwik',
	'General_DownloadFullVersion' => '%1$sLast ned%2$s fullversjonen! Sjekk ut %3$s',
	'General_NewUpdatePiwikX' => 'Ny Oppdatering: Piwik %s',
	'General_AboutPiwikX' => 'Om Piwik %s',
	'General_PiwikXIsAvailablePleaseUpdateNow' => 'Piwik %1$s er komen. %2$s Venlegast oppdater nå!%3$s (sjå %4$s endringar%5$s).',
	'General_PiwikXIsAvailablePleaseNotifyPiwikAdmin' => '%s er tilgjengeleg. ...',
	'General_BackToPiwik' => 'Attende til Piwik',
	'General_ShortMonth_1' => 'Jan',
	'General_ShortMonth_2' => 'Feb',
	'General_ShortMonth_3' => 'Mar',
	'General_ShortMonth_4' => 'Apr',
	'General_ShortMonth_5' => 'Mai',
	'General_ShortMonth_6' => 'Jun',
	'General_ShortMonth_7' => 'Jul',
	'General_ShortMonth_8' => 'Aug',
	'General_ShortMonth_9' => 'Sep',
	'General_ShortMonth_10' => 'Okt',
	'General_ShortMonth_11' => 'Nov',
	'General_ShortMonth_12' => 'Des',
	'General_LongMonth_1' => 'Januar',
	'General_LongMonth_2' => 'Februar',
	'General_LongMonth_3' => 'Mars',
	'General_LongMonth_4' => 'April',
	'General_LongMonth_5' => 'Mai',
	'General_LongMonth_6' => 'Juni',
	'General_LongMonth_7' => 'Juli',
	'General_LongMonth_8' => 'August',
	'General_LongMonth_9' => 'September',
	'General_LongMonth_10' => 'Oktober',
	'General_LongMonth_11' => 'November',
	'General_LongMonth_12' => 'Desember',
	'General_ShortDay_1' => 'Mån',
	'General_ShortDay_2' => 'Tys',
	'General_ShortDay_3' => 'Ons',
	'General_ShortDay_4' => 'Tor',
	'General_ShortDay_5' => 'Fre',
	'General_ShortDay_6' => 'Lau',
	'General_ShortDay_7' => 'Sun',
	'General_LongDay_1' => 'Måndag',
	'General_LongDay_2' => 'Tysdag',
	'General_LongDay_3' => 'Onsdag',
	'General_LongDay_4' => 'Torsdag',
	'General_LongDay_5' => 'Fredag',
	'General_LongDay_6' => 'Laurdag',
	'General_LongDay_7' => 'Sundag',
	'General_Daily' => 'Dagleg',
	'General_Weekly' => 'Kvar veke',
	'General_Monthly' => 'Kvar månad',
	'General_ExceptionDatabaseVersion' => 'Din %1$s versjon er %2$s, men Piwik krev minst %3$s.',
	'General_ExceptionMissingFile' => 'Manglar fila: %s',
	'General_ExceptionFilesizeMismatch' => 'Filstorleiken stemmer ikkje: %1$s (forventa lengde: %2$s, fann: %3$s)',
	'General_ExceptionFileIntegrity' => 'Integritetssjekk feila: %s',
	'General_ExceptionNonceMismatch' => 'Kunne ikkje bekrefta tryggleiksteiknet for dette skjemaet.',
	'General_ExceptionMethodNotFound' => 'Metoden \'%s\' finnes ikkje, eller er utilgjengeleg i modulen \'%s\'.',
	'General_ExceptionUndeletableFile' => 'Kunne ikkje sletta %s',
	'General_ExceptionPrivilege' => 'Du kan ikkje nå denne ressursen, av di den krev \'%s\' tilgang.',
	'General_ExceptionPrivilegeAtLeastOneWebsite' => 'Du kan ikkje nå denne ressursen, av di den krev \'%s\' tilgang for minst ein nettstad.',
	'General_ExceptionPrivilegeAccessWebsite' => 'Du kan ikkje nå denne ressursen, av di den krev \'%s\' tilgang for nettstaden id = %d.',
	'General_ExceptionInvalidArchiveTimeToLive' => 'Levetida for dagens arkiv må vera lengre enn null sekund',
	'General_ExceptionConfigurationFileNotFound' => 'Konfigurasjonsfila {%s} vart ikkje funne.',
	'General_ExceptionUnreadableFileDisabledMethod' => 'Konfigurasjonsfila {%s} kunne ikkje bli lest. Din vert har kanskje skrudd av %s.',
	'General_ExceptionInvalidToken' => 'Teiknet er ikkje gyldig.',
	'General_ExceptionInvalidDateFormat' => 'Datoformatet må vera: %s eller eit anna nøkkelord som er støtta av %s funksjonen (sjå %s for meir informasjon)',
	'General_ExceptionLanguageFileNotFound' => 'Språkfila \'%s\' vart ikkje funnen.',
	'General_WarningFileIntegritySkipped' => 'Utviklingsmiljø merka. Sjekking av filintegritet er ignorert.',
	'General_WarningFileIntegrityNoManifest' => 'Sjekking av filintegritet kunne ikkje bli utført av di manifest.inc.php manglar.',
	'General_WarningFileIntegrityNoMd5file' => 'Sjekking av filintegritet kunne ikkje bli utført av di md5_file()-funksjonen manglar.',
	'General_FileIntegrityWarningExplanation' => 'Sjekking av filintegritet feila med feilmeldingar. Dette skyldast truleg at nokre av Piwik sine filar berre vart delvis eller feilaktig lasta opp. Du bør lasta opp Piwik på nytt i BINARY modus og oppfriska denne siden til feilmeldingane forsvinn.',
	'Actions_Actions' => 'Handlingar',
	'Actions_SubmenuPages' => 'Sider',
	'Actions_SubmenuOutlinks' => 'Utlenkjer',
	'Actions_SubmenuDownloads' => 'Nedlastingar',
	'Actions_ColumnClicks' => 'Klikk',
	'Actions_ColumnUniqueClicks' => 'Unike klikk',
	'Actions_ColumnDownloads' => 'Nedlastingar',
	'Actions_ColumnUniqueDownloads' => 'Unike nedlastingar',
	'Actions_ColumnPageName' => 'Sidenamn',
	'Actions_ColumnPageURL' => 'Side URL',
	'Actions_ColumnClickedURL' => 'Klikka URL',
	'Actions_ColumnDownloadURL' => 'Nedlasta URL',
	'API_LoadedAPIs' => 'Lasta vellykka %s APIar',
	'CoreAdminHome_MenuGeneralSettings' => 'Generelle innstillingar',
	'CoreAdminHome_Administration' => 'Administrasjon',
	'CoreHome_CategoryNoData' => 'Inga data i denne kategorien. Prøv \'Inkluder heile datasettet\'',
	'CoreHome_ShowJSCode' => 'Vis JavaScriptkoden for å setja inn.',
	'CoreHome_PageOf_js' => '%1$s av %2$s',
	'CoreHome_PeriodDay' => 'Dag',
	'CoreHome_PeriodWeek' => 'Veke',
	'CoreHome_PeriodMonth' => 'Månad',
	'CoreHome_PeriodYear' => 'År',
	'CoreHome_PeriodDays' => 'dagar',
	'CoreHome_PeriodWeeks' => 'veker',
	'CoreHome_PeriodMonths' => 'månader',
	'CoreHome_PeriodYears' => 'år',
	'CoreHome_DaySu_js' => 'Su',
	'CoreHome_DayMo_js' => 'Må',
	'CoreHome_DayTu_js' => 'Ti',
	'CoreHome_DayWe_js' => 'On',
	'CoreHome_DayTh_js' => 'To',
	'CoreHome_DayFr_js' => 'Fr',
	'CoreHome_DaySa_js' => 'La',
	'CoreHome_ShortDay_1_js' => 'Søn',
	'CoreHome_ShortDay_2_js' => 'Mån',
	'CoreHome_ShortDay_3_js' => 'Tys',
	'CoreHome_ShortDay_4_js' => 'Ons',
	'CoreHome_ShortDay_5_js' => 'Tor',
	'CoreHome_ShortDay_6_js' => 'Fre',
	'CoreHome_ShortDay_7_js' => 'Lau',
	'CoreHome_LongDay_1_js' => 'Søndag',
	'CoreHome_LongDay_2_js' => 'Måndag',
	'CoreHome_LongDay_3_js' => 'Tysdag',
	'CoreHome_LongDay_4_js' => 'Onsdag',
	'CoreHome_LongDay_5_js' => 'Torsdag',
	'CoreHome_LongDay_6_js' => 'Fredag',
	'CoreHome_LongDay_7_js' => 'Laurdag',
	'CoreHome_ShortMonth_1_js' => 'Jan',
	'CoreHome_ShortMonth_2_js' => 'Feb',
	'CoreHome_ShortMonth_3_js' => 'Mar',
	'CoreHome_ShortMonth_4_js' => 'Apr',
	'CoreHome_ShortMonth_5_js' => 'Mai',
	'CoreHome_ShortMonth_6_js' => 'Jun',
	'CoreHome_ShortMonth_7_js' => 'Jul',
	'CoreHome_ShortMonth_8_js' => 'Aug',
	'CoreHome_ShortMonth_9_js' => 'Sep',
	'CoreHome_ShortMonth_10_js' => 'Okt',
	'CoreHome_ShortMonth_11_js' => 'Nov',
	'CoreHome_ShortMonth_12_js' => 'Des',
	'CoreHome_MonthJanuary_js' => 'Januar',
	'CoreHome_MonthFebruary_js' => 'Februar',
	'CoreHome_MonthMarch_js' => 'Mars',
	'CoreHome_MonthApril_js' => 'April',
	'CoreHome_MonthMay_js' => 'Mai',
	'CoreHome_MonthJune_js' => 'Juni',
	'CoreHome_MonthJuly_js' => 'Juli',
	'CoreHome_MonthAugust_js' => 'August',
	'CoreHome_MonthSeptember_js' => 'September',
	'CoreHome_MonthOctober_js' => 'Oktober',
	'CoreHome_MonthNovember_js' => 'November',
	'CoreHome_MonthDecember_js' => 'Desember',
	'CorePluginsAdmin_PluginDescription' => 'Administrasjon av innstikk.',
	'CorePluginsAdmin_Plugins' => 'Innstikk',
	'CorePluginsAdmin_PluginsManagement' => 'Innstikkstyring',
	'CorePluginsAdmin_MainDescription' => 'Innstikk utvidar funksjonane til Piwik. Når eit innstikk er lagt til, kan du slå det av og på her.',
	'CorePluginsAdmin_Plugin' => 'Innstikk',
	'CorePluginsAdmin_Version' => 'Versjon',
	'CorePluginsAdmin_Status' => 'Status',
	'CorePluginsAdmin_Action' => 'Handling',
	'CorePluginsAdmin_PluginHomepage' => 'Innstikkets nettside',
	'CorePluginsAdmin_Activated' => 'På',
	'CorePluginsAdmin_Active' => 'Aktivt',
	'CorePluginsAdmin_Inactive' => 'Av',
	'CorePluginsAdmin_Deactivate' => 'Slå av',
	'CorePluginsAdmin_Activate' => 'Slå på',
	'CorePluginsAdmin_MenuPlugins' => 'Innstikk',
	'CoreUpdater_PluginDescription' => 'Piwik si oppdateringsmekanisme',
	'CoreUpdater_UpdateTitle' => 'Piwik › Oppdatering',
	'CoreUpdater_DatabaseUpgradeRequired' => 'Databaseoppdatering krevjast',
	'CoreUpdater_YourDatabaseIsOutOfDate' => 'Piwik databasa di er gamal, og må bli oppgradert før du kan fortsetja.',
	'CoreUpdater_PiwikWillBeUpgradedFromVersionXToVersionY' => 'Piwik databasa vil bli oppgradert frå versjon %1$s til den nye versjonen %2$s.',
	'CoreUpdater_TheFollowingPluginsWillBeUpgradedX' => 'Dei følgjande innstikka vil bli oppdatert: %s.',
	'CoreUpdater_NoteForLargePiwikInstances' => 'Viktig melding for store Piwik-installasjonar',
	'CoreUpdater_TheUpgradeProcessMayFailExecuteCommand' => 'Om du har ein stor Piwik database, kan det hende at oppdateringa tek for lang tid i nettlesaren. Då kan du køyre oppdateringane frå kommandolinja: %s',
	'CoreUpdater_YouCouldManuallyExecuteSqlQueries' => 'Om du ikkje kan nytta kommandolinja og oppdateringa feiler (pga tidsavbrot mot databasen, tidsavbrot i nettlesaren, eller andre problem), kan du manuelt køyre SQL-spurnadane for å oppdatera Piwik.',
	'CoreUpdater_ClickHereToViewSqlQueries' => 'Klikk her for å sjå og kopiera SQL-spurnadene som vil bli køyrd',
	'CoreUpdater_NoteItIsExpectedThatQueriesFail' => 'Merk: om du køyrer spurnadene manuelt, er det forventa at nokon vil feila. Om det skjer, kan du berre ignorera dei og fortsetja på lista.',
	'CoreUpdater_ReadyToGo' => 'Er du klar?',
	'CoreUpdater_TheUpgradeProcessMayTakeAWhilePleaseBePatient' => 'Oppdateringa av databasa kan ta litt tid, så ha tolmod.',
	'CoreUpdater_UpgradePiwik' => 'Oppdater Piwik',
	'CoreUpdater_ErrorDIYHelp_5' => 'Rapporter problemet (og løysinga) slik at Piwik kan bli forbetra',
	'CoreUpdater_HelpMessageContent' => 'Les %1$s Piwik OBS %2$s som forklarar dei vanlegaste feila under oppdatering. %3$s Spør dine systemadministratorar, dei kan kanskje hjelpa deg me feilen, som sannsynlegvis hev noko med MySQL databasa di å gjera.',
	'CoreUpdater_CriticalErrorDuringTheUpgradeProcess' => 'Kritisk feil under oppdateringa:',
	'CoreUpdater_HelpMessageIntroductionWhenError' => 'Ovanfor står kjernefeilmeldinga. Den burde forklare grunnen, men om du treng meir hjelp:',
	'CoreUpdater_HelpMessageIntroductionWhenWarning' => 'Oppdateringa var vellykka, med det var problem i prosessen. Sjå dei øvrige forklaringane for detaljar. For meir hjelp:',
	'CoreUpdater_UpgradeComplete' => 'Oppgradering ferdig!',
	'CoreUpdater_WarningMessages' => 'Åtvaringar:',
	'CoreUpdater_ErrorDuringPluginsUpdates' => 'Feil under oppdatering av innstikk:',
	'CoreUpdater_WeAutomaticallyDeactivatedTheFollowingPlugins' => 'Me slo automatisk av føljande innstikk: %s',
	'CoreUpdater_PiwikHasBeenSuccessfullyUpgraded' => 'Oppdateringa var vellykka!',
	'CoreUpdater_ContinueToPiwik' => 'Fortsett til Piwik',
	'CoreUpdater_UpdateAutomatically' => 'Oppdater automatisk',
	'CoreUpdater_ThereIsNewVersionAvailableForUpdate' => 'Det er ein ny versjon av Piwik tilgjengeleg for oppdatering',
	'CoreUpdater_YouCanUpgradeAutomaticallyOrDownloadPackage' => 'Du kan oppdatera til versjon %s automatisk, eller laste ned pakka og installera ho manuelt:',
	'CoreUpdater_YouMustDownloadPackageOrFixPermissions' => 'Piwik kan ikkje overskriva den gjeldande installasjonen. Du kan enten fikse katalog/filtilgangen, eller laste ned pakken og installera versjon %s manuelt:',
	'CoreUpdater_DownloadX' => 'Last ned %s',
	'CoreUpdater_DownloadingUpdateFromX' => 'Lastar ned oppdatering frå %s',
	'CoreUpdater_UnpackingTheUpdate' => 'Pakkar ut oppdateringa',
	'CoreUpdater_VerifyingUnpackedFiles' => 'Sjekkar filane',
	'CoreUpdater_CreatingBackupOfConfigurationFile' => 'Lagar tryggleikskopi av konfigurasjonsfila %s',
	'CoreUpdater_InstallingTheLatestVersion' => 'Installerer siste versjon',
	'CoreUpdater_PiwikUpdatedSuccessfully' => 'Oppdateringa av Piwik vart vellykka!',
	'CoreUpdater_EmptyDatabaseError' => 'Databasen %s er tom. Du må endra eller fjerna Piwik si konfigurasjonsfil.',
	'CoreUpdater_ExceptionAlreadyLatestVersion' => 'Din versjon av Piwik %s er oppdatert.',
	'CoreUpdater_ExceptionArchiveIncompatible' => 'Ugyldig arkiv: %s',
	'CoreUpdater_ExceptionArchiveEmpty' => 'Tomt arkiv.',
	'CoreUpdater_ExceptionArchiveIncomplete' => 'Arkivet er mangelfullt: nokon filar manglar (td %s).',
	'Dashboard_Dashboard' => 'Dashbord',
	'Dashboard_DeleteWidgetConfirm' => 'Er du sikker på at du vil fjerna denne dingsen frå ditt dashbord?',
	'Dashboard_SelectWidget' => 'Vel den dingsen du vil legga til dashbordet',
	'Dashboard_AddPreviewedWidget_js' => 'Legg framvist dings til dashbordet',
	'Dashboard_WidgetPreview_js' => 'Dingsframvising',
	'Dashboard_Close_js' => 'Lukk',
	'Dashboard_TitleWidgetInDashboard_js' => 'Dingsen finnes allereie i dashbordet',
	'Dashboard_TitleClickToAdd_js' => 'Klikk for å leggja til i dashbordet',
	'Dashboard_LoadingWidget_js' => 'Lastar dings, venligast vent...',
	'Dashboard_WidgetNotFound_js' => 'Dingsen vart ikkje funnen',
	'DBStats_PluginDescription' => 'Dette innstikket rapporterer Piwiks bruk av MySQL-databasen.',
	'DBStats_DatabaseUsage' => 'Databasebruk',
	'DBStats_MainDescription' => 'Piwik lagrar alle dine nettsanalysedata i MySQL-databasen. Nett no nyttar Piwiks tabellar %s.',
	'DBStats_LearnMore' => 'For å læra meir om korleis Piwik prosesserar data, og korleis gjera at Piwik virkar bra for nettstader med medium og høg trafikk, sjå dokumentasjonen %s.',
	'DBStats_Table' => 'Tabell',
	'DBStats_RowCount' => 'Rad',
	'DBStats_DataSize' => 'Datastorleik',
	'DBStats_IndexSize' => 'Indeksstorleik',
	'DBStats_TotalSize' => 'Samla storleik',
	'Feedback_WhyAreMyVisitsNoTracked' => 'Kvifor blir ikkje vitjarane på nettstaden min registrert?',
	'Feedback_HowToExclude' => 'Korleis ekskluderer eg registrering av mine eige vitjingar?',
	'Feedback_WhyWrongCountry' => 'Kvifor visar Piwik min vitjing frå feil land?',
	'Feedback_HowToAnonymizeIP' => 'Korleis maskerer eg vitjarane sine ip-adresser i databasen?',
	'Feedback_ContactThePiwikTeam' => 'Kontakt Piwik-teamet!',
	'Feedback_IWantTo' => 'Eg ønskjer:',
	'Feedback_CategoryShareStory' => 'Del ein suksesshistorie i bruken av Piwik',
	'Feedback_CategorySponsor' => 'Spons Piwik',
	'Feedback_CategoryHire' => 'Hyr ein Piwik-konsulent',
	'Feedback_CategorySecurity' => 'Rapporter ein tryggleikssak',
	'Feedback_MyEmailAddress' => 'Min epostadresse:',
	'Feedback_MyMessage' => 'Min melding:',
	'Feedback_SendFeedback' => 'Send attendemelding',
	'Feedback_MessageSent' => 'Meldinga din vart sendt til Piwik-teamet.',
	'Feedback_ThankYou' => 'Takk for at hjelper oss med å forbetra Piwik!',
	'Feedback_ThePiwikTeam' => 'Piwik-teamet',
	'Feedback_ExceptionBodyLength' => 'Meldinga må vera minst %s teikn lang.',
	'Feedback_ExceptionNoUrls' => 'For å forhindra søppelpost, kan ikkje meldinga innehalda URLar.',
	'Goals_Goals' => 'Mål',
	'Goals_GoalsOverview' => 'Måloversikt',
	'Goals_ColumnConversions' => 'Overgangar',
	'Goals_ColumnRevenue' => 'Forteneste',
	'Goals_GoalX' => 'Mål %s',
	'Goals_AddNewGoal' => 'Legg til eit nytt mål',
	'Goals_UpdateGoal_js' => 'Oppdater mål',
	'Goals_DeleteGoalConfirm_js' => 'Er du sikker på at du vil sletta målet %s?',
	'Goals_CreateNewGOal' => 'Opprett eit nytt mål',
	'Goals_ViewAndEditGoals' => 'Vis og endre mål',
	'Goals_GoalName' => 'Målnamn',
	'Goals_GoalIsTriggeredWhen' => 'Målet er nådd når',
	'Goals_WhenVisitors' => 'Når vitjarar',
	'Goals_Manually' => 'manuelt',
	'Goals_VisitUrl' => 'Vitj ein gitt URL (side eller gruppe av sider)',
	'Goals_URL' => 'URL',
	'Goals_Filename' => 'filnamn',
	'Goals_ExternalWebsiteUrl' => 'URLen til den eksterne nettstaden',
	'Goals_Download' => 'Last ned ein fil',
	'Goals_ClickOutlink' => 'Klikk på ein lenke til ein ekstern nettstad',
	'Goals_Optional' => '(frivillig)',
	'Goals_Contains' => 'inneheld %s',
	'Goals_IsExactly' => 'er nøyaktig %s',
	'Goals_Pattern' => 'Mønster',
	'Installation_Installation' => 'Installasjon',
	'Installation_InstallationStatus' => 'Installasjonstatus',
	'Installation_PercentDone' => '%s %% Ferdig',
	'Installation_NoConfigFound' => 'Du prøvar å nå ein Piwikside, men konfigurasjonen vart ikkje funnen.<br /><b>  » Du kan <a href=\'index.php\'>installera Piwik nå</a></b><br /><small>    Om du allereie har hatt Piwik installert og hev nokre tabellar i databasen treng du ikkje bekymra deg. Du kan nytta dei same tabellane og data.    </small>',
	'Installation_DatabaseSetup' => 'Databaseoppsett',
	'Installation_DatabaseSetupServer' => 'databasetenar',
	'Installation_DatabaseSetupLogin' => 'brukarnamn',
	'Installation_DatabaseSetupPassword' => 'passord',
	'Installation_DatabaseSetupDatabaseName' => 'databasenamn',
	'Installation_DatabaseSetupTablePrefix' => 'tabellprefiks',
	'Installation_DatabaseSetupAdapter' => 'adapter',
	'Installation_DatabaseCheck' => 'Databasesjekk',
	'Installation_JsTag' => 'JavaScript tagg',
	'Installation_Congratulations' => 'Gratulerer',
	'Installation_CongratulationsHelp' => '<p>Gratulerer! Din Piwik installasjon er ferdog.</p><p>Ver sikker på at JavaScript koden er skrevet på sidene dine, og vent på dine første vitjarar!</p>',
	'Installation_ContinueToPiwik' => 'Forsett til Piwik',
	'Installation_SetupWebsite' => 'Sett opp ei nettstad',
	'Installation_SetupWebsiteError' => 'Det skjedde ein feil då nettsiden blei lagt til',
	'Installation_SuperUserLogin' => 'superbrukar pålogging',
	'Installation_Password' => 'passord',
	'Installation_PasswordRepeat' => 'passord (gjenteken)',
	'Installation_Email' => 'epost',
	'Installation_SecurityNewsletter' => 'send meg epost når det kjem oppdateringar og tryggleiksvarslingar',
	'Installation_CommunityNewsletter' => 'email me with community updates (new plugins, new features, etc.)    send meg epost når det kjem oppdateringar frå fellesskapet (nye innstikk, funksjonar osb.)',
	'Installation_PasswordDoNotMatch' => 'Passorda stemmer ikkje',
	'Installation_SystemCheck' => 'Systemsjekk',
	'Installation_SystemCheckPhp' => 'PHP utgåve',
	'Installation_SystemCheckWriteDirs' => 'Katalogar med skrivetilgang',
	'Installation_SystemCheckWriteDirsHelp' => 'To fix this error on your Linux system, try typing in the following command(s)    For å fiksa denne feilen på din Linux tenar, prøv den/dei føljande kommandoen(e)',
	'Installation_SystemCheckMemoryLimit' => 'Minnegrense',
	'Installation_SystemCheckMemoryLimitHelp' => 'På eit nettsted me høg trafikk, kan arkiveringsprosessen nytta meir minne enn den hev lov til.<br />Sjå innstillinga memory_limit i din php.ini fil om nødvendig.',
	'Installation_SystemCheckOpenURL' => 'Open URL',
	'Installation_SystemCheckGD' => 'GD > 2.x (biletebehandling)',
	'Installation_SystemCheckGDHelp' => 'Gnistlinjene (små bilete) vil ikkje virka.',
	'Installation_SystemCheckFunctions' => 'Nødvendige funksjonar',
	'Installation_SystemCheckTimeLimitHelp' => 'På eit nettsted me høg trafikk, kan arkiveringsprosessen nytta meir tid enn den hev lov til.<br />Sjå innstillinga max_execution_time i din php.ini fil om nødvendig.',
	'Installation_SystemCheckMailHelp' => 'Attendemeldingar og \'Tapt Passord\'-meldingar vart ikkje sendt uten mail().',
	'Installation_SystemCheckFileIntegrity' => 'Filintegritet',
	'Installation_SystemCheckAutoUpdateHelp' => 'Merk: Piwiks ettklikks oppdatering krev skrivetilgang til Piwik-katalogen og dens innhald.',
	'Installation_SystemCheckError' => 'Det skjedde ein feil - du må fiksa han før du kan fortsetje',
	'Installation_SystemCheckWarning' => 'Piwik vil virka som normalt, men det kan hende at nokon funksjonar manglar',
	'Installation_Tables' => 'Opprettar tabellane',
	'Installation_TablesWithSameNamesFound' => 'Nokre %1$s tabellar i databasen din %2$s hev dei same namna som dei tabellane Piwik prøvar å lage',
	'Installation_TablesFound' => 'Dei føljande tabellane vart funnen i databasen',
	'Installation_TablesWarningHelp' => 'Du må velja om du vil nytta dei eksisterande tabellane slik dei er, eller å sletta dei og starta på nytt.',
	'Installation_TablesReuse' => 'Nytt dei eksisterande tabellane',
	'Installation_TablesDelete' => 'Slett dei eksisterande tabellane',
	'Installation_TablesDeletedSuccess' => 'Slettinga av dei eksisterande tabellane vart vellykka',
	'Installation_TablesCreatedSuccess' => 'Opprettinga av tabellane vart vellykka!',
	'Installation_DatabaseCreatedSuccess' => 'Oppretting av databasen %s vart vellykka!',
	'Installation_GoBackAndDefinePrefix' => 'Gå tilbake og vel ein prefiks for Piwik tabellane',
	'Installation_ConfirmDeleteExistingTables' => 'Er du sikker på at du vil sletta tabellane: %s ifrå databasen?    ÅTVARING: DEI KAN IKKJE BLI GJENOPPRETTA!',
	'Installation_Welcome' => 'Velkommen!',
	'Installation_WelcomeHelp' => '<p>Piwik er ein open kjeldekode nettsanalyseprogramvare som gjer det enkelt å henta ut informasjonen du ønskjer frå dine vitjarar.</p><p>Denne prosessen er delt opp i %s enkle steg, og tek omkring 5 minuttar.</p>',
	'Live_PluginDescription' => 'Spioner på vitjarane dine i sanntid!',
	'Live_VisitorLog' => 'Vitjarlogg',
	'Live_Time' => 'Tid',
	'Login_LoginPasswordNotCorrect' => 'Brukarnamn og passord er feil',
	'Login_Password' => 'Passord',
	'Login_PasswordRepeat' => 'Passord (gjenta)',
	'Login_ChangePassword' => 'Bytt passord',
	'Login_LoginOrEmail' => 'Brukarnamn eller epost',
	'Login_LogIn' => 'Logg på',
	'Login_Logout' => 'Logg ut',
	'Login_LostYourPassword' => 'Hev du gløymd passordet?',
	'Login_RemindPassword' => 'Minn meg på passordet',
	'Login_PasswordReminder' => 'Skriv inn enten ditt brukarnamn eller din epost-adresse. Du vil få eit nytt passord via epost.',
	'Login_PasswordsDoNotMatch' => 'Passorda stemmer ikkje',
	'Login_PasswordSuccessfullyChanged' => 'Passordbytte vart vellykka!',
	'Login_InvalidUsernameEmail' => 'Ugyldig brukarnamn og/eller epost-adresse',
	'Login_MailTopicPasswordRecovery' => 'Passordpåminning',
	'Login_PasswordSent' => 'Passordet har akkurat blitt sendt. Sjekk eposten din.',
	'Login_ContactAdmin' => 'Mulig grunn: tenaren din hev slått av mail() funksjonen. <br />Kontakt din Piwik administrator.',
	'MultiSites_Evolution' => 'Evolusjon',
	'Referers_Referers' => 'Referansar',
	'Referers_SearchEngines' => 'Søkjemotorar',
	'Referers_Keywords' => 'Nøkkelord',
	'Referers_DirectEntry' => 'Direkte vitjing',
	'Referers_Websites' => 'Nettstader',
	'Referers_Campaigns' => 'Kampanjar',
	'Referers_Evolution' => 'Utvikling over perioden',
	'Referers_Type' => 'Referansetype',
	'Referers_ColumnRefererType' => 'Referansetype',
	'Referers_ColumnSearchEngine' => 'Søkjemotor',
	'Referers_ColumnWebsite' => 'Nettstad',
	'Referers_ColumnWebsitePage' => 'Nettstadside',
	'Referers_ColumnKeyword' => 'Nøkkelord',
	'Referers_ColumnCampaign' => 'Kampanje',
	'Referers_DetailsByRefererType' => 'Detaljar sortert etter referansetype',
	'Referers_TypeDirectEntries' => '%s direkte vitjarar',
	'Referers_TypeSearchEngines' => '%s frå søkjemotorer',
	'Referers_TypeWebsites' => '%s frå nettstader',
	'Referers_TypeCampaigns' => '%s frå kampanjar',
	'Referers_Distinct' => 'Distinkte referansar etter referansetype',
	'Referers_DistinctSearchEngines' => 'distinkte søkjemotorer',
	'Referers_DistinctKeywords' => 'distinkte nøkkelord',
	'Referers_DistinctCampaigns' => 'distinkte kampanjar',
	'Referers_DistinctWebsites' => 'distinkte nettstader',
	'Referers_SubmenuSearchEngines' => 'Søkjemotorar og nøkkelord',
	'Referers_SubmenuWebsites' => 'Nettstader',
	'Referers_SubmenuCampaigns' => 'Kampanjar',
	'Referers_WidgetKeywords' => 'Liste over nøkkelord',
	'Referers_WidgetCampaigns' => 'Liste over kampanjar',
	'Referers_WidgetExternalWebsites' => 'Liste over eksterne nettsider',
	'Referers_WidgetSearchEngines' => 'Beste søkjemotorar',
	'Referers_WidgetOverview' => 'Oversikt',
	'SecurityInfo_Security' => 'Tryggleik',
	'SecurityInfo_Test' => 'Test',
	'SecurityInfo_Result' => 'Resultat',
	'SEO_Backlinks' => 'Attendelenkjar',
	'SEO_Pages' => 'Sider',
	'SitesManager_Sites' => 'Nettstadar',
	'SitesManager_WebsitesManagement' => 'Nettstadsbehandling',
	'SitesManager_MainDescription' => 'Your Web Analytics reports need Websites! Add, update, delete Websites, and show the JavaScript to insert in your pages.    Din nettanalyserapport treng nettstader! Legg til, oppdater og fjern nettstader, samt vis javaScript koden som trengs på sidene dine.',
	'SitesManager_JsTrackingTag' => 'JavaScript Sporing skode',
	'SitesManager_JsTrackingTagHelp' => 'Here is the JavaScript Tracking tag to include on all your pages    Her er JavaScript sporingskoden som du på leggja ved alle sidene dine',
	'SitesManager_ShowTrackingTag' => 'vis sporingskode',
	'SitesManager_NoWebsites' => 'Du har inga nettstader å administrera.',
	'SitesManager_AddSite' => 'Legg til ein ny nettstad',
	'SitesManager_Urls' => 'Adresser',
	'SitesManager_MenuSites' => 'Nettstader',
	'SitesManager_DeleteConfirm_js' => 'Er du sikker på at du vil sletta denne nettstaden %s?',
	'SitesManager_ExceptionDeleteSite' => 'It is not possible to delete this website as it is the only registered website. Add a new website first, then delete this one.    Det er ikkje mulig å sletta denne nettstaden, ettersom det er den einaste registrerte nettstaden. Legg til ein ny nettstad først, så kan du sletta denne etterpå.',
	'SitesManager_ExceptionNoUrl' => 'Du må skriva minst ein adresse for nettstaden.',
	'SitesManager_ExceptionEmptyName' => 'Stadsnamnet kan ikkje vera tomt.',
	'SitesManager_ExceptionInvalidUrl' => 'Adressa \'%s\' er ikkje ein gyldig adresse (URL)',
	'SitesManager_ExceptionInvalidTimezone' => 'Tidssonen "%s" er ugyldig. Skriv ein gyldig tidssone.',
	'SitesManager_ExcludedIps' => 'Ekskluderte IPar',
	'SitesManager_GlobalListExcludedIps' => 'Global liste over ekskluderte IPar',
	'SitesManager_YourCurrentIpAddressIs' => 'Din gjeldande IP-adresse er %s',
	'SitesManager_SelectACity' => 'Vel ein by',
	'SitesManager_ChooseCityInSameTimezoneAsYou' => 'Vel ein by i same tidssone som deg.',
	'SitesManager_Currency' => 'Valuta',
	'TranslationsAdmin_PluginDescription' => 'Hjelp med å omsetja Piwik til ditt språk.',
	'TranslationsAdmin_MenuTranslations' => 'Omsetjingar',
	'TranslationsAdmin_MenuLanguages' => 'Språk',
	'TranslationsAdmin_LanguageCode' => 'Språkkode',
	'TranslationsAdmin_Plugin' => 'Innstikk',
	'TranslationsAdmin_Definition' => 'Definisjon',
	'TranslationsAdmin_DefaultString' => 'Standard tekst(Engelsk)',
	'TranslationsAdmin_TranslationString' => 'Omsetjing (gjeldande språk: %s)',
	'TranslationsAdmin_Translations' => 'Omsetjingar',
	'TranslationsAdmin_FixPermissions' => 'Fiks feil i filsystemet',
	'TranslationsAdmin_AddLanguage' => 'Legg til eit nytt språk',
	'TranslationsAdmin_Export' => 'Eksporter språk',
	'TranslationsAdmin_Import' => 'Importer språk',
	'UserCountry_Country' => 'Land',
	'UserCountry_Continent' => 'Kontinent',
	'UserCountry_DistinctCountries' => '%s distinkte land',
	'UserCountry_Location' => 'Plass',
	'UserCountry_SubmenuLocations' => 'Plassar',
	'UserCountry_WidgetContinents' => 'Vitjarars kontinent',
	'UserCountry_WidgetCountries' => 'Vitjarars land',
	'UserCountry_country_ac' => 'Ascension øyane',
	'UserCountry_country_ad' => 'Andorra',
	'UserCountry_country_ae' => 'Dei Foreinte Arabiske Emiratar',
	'UserCountry_country_af' => 'Afghanistan',
	'UserCountry_country_ag' => 'Antigua og Barbuda',
	'UserCountry_country_ai' => 'Anguilla',
	'UserCountry_country_al' => 'Albania',
	'UserCountry_country_am' => 'Armenia',
	'UserCountry_country_an' => 'Dei Nederlandske Antillane',
	'UserCountry_country_ao' => 'Angola',
	'UserCountry_country_aq' => 'Antarktis',
	'UserCountry_country_ar' => 'Argentina',
	'UserCountry_country_as' => 'Amerikansk Samoa',
	'UserCountry_country_at' => 'Østerrike',
	'UserCountry_country_au' => 'Australia',
	'UserCountry_country_aw' => 'Aruba',
	'UserCountry_country_ax' => 'Åland',
	'UserCountry_country_az' => 'Azerbaijan',
	'UserCountry_country_ba' => 'Bosnia og Herzegovina',
	'UserCountry_country_bb' => 'Barbados',
	'UserCountry_country_bd' => 'Bangladesh',
	'UserCountry_country_be' => 'Belgia',
	'UserCountry_country_bf' => 'Burkina Faso',
	'UserCountry_country_bg' => 'Bulgaria',
	'UserCountry_country_bh' => 'Bahrain',
	'UserCountry_country_bi' => 'Burundi',
	'UserCountry_country_bj' => 'Benin',
	'UserCountry_country_bl' => 'Saint Barthelemy',
	'UserCountry_country_bm' => 'Bermuda',
	'UserCountry_country_bn' => 'Bruneo',
	'UserCountry_country_bo' => 'Bolivia',
	'UserCountry_country_br' => 'Brazil',
	'UserCountry_country_bs' => 'Bahamas',
	'UserCountry_country_bt' => 'Bhutan',
	'UserCountry_country_bu' => 'Burma',
	'UserCountry_country_bv' => 'Bouvetøya',
	'UserCountry_country_bw' => 'Botswana',
	'UserCountry_country_by' => 'Belarus',
	'UserCountry_country_bz' => 'Belize',
	'UserCountry_country_ca' => 'Canada',
	'UserCountry_country_cc' => 'Kokosøyane',
	'UserCountry_country_cd' => 'Kongo, Den Demokratiske Republikken av',
	'UserCountry_country_cf' => 'Den Sentralafrikanske Republikken',
	'UserCountry_country_cg' => 'Kongo',
	'UserCountry_country_ch' => 'Sveits',
	'UserCountry_country_ci' => 'Elfenbeinskysten',
	'UserCountry_country_ck' => 'Cookøyane',
	'UserCountry_country_cl' => 'Chile',
	'UserCountry_country_cm' => 'Kamerun',
	'UserCountry_country_cn' => 'Kina',
	'UserCountry_country_co' => 'Colombia',
	'UserCountry_country_cp' => 'Clipperton Island',
	'UserCountry_country_cr' => 'Costa Rica',
	'UserCountry_country_cs' => 'Serbia Montenegro',
	'UserCountry_country_cu' => 'Cuba',
	'UserCountry_country_cv' => 'Cape Verde',
	'UserCountry_country_cx' => 'Christmas Island',
	'UserCountry_country_cy' => 'Kypros',
	'UserCountry_country_cz' => 'Tsjekkia',
	'UserCountry_country_de' => 'Tyskland',
	'UserCountry_country_dg' => 'Diego Garcia',
	'UserCountry_country_dj' => 'Djibouti',
	'UserCountry_country_dk' => 'Danmark',
	'UserCountry_country_dm' => 'Dominica',
	'UserCountry_country_do' => 'Den dominikanske republikken',
	'UserCountry_country_dz' => 'Algerie',
	'UserCountry_country_ea' => 'Ceuta og Melilla',
	'UserCountry_country_ec' => 'Ecuador',
	'UserCountry_country_ee' => 'Estonia',
	'UserCountry_country_eg' => 'Egypt',
	'UserCountry_country_eh' => 'Vest Sahara',
	'UserCountry_country_er' => 'Eritrea',
	'UserCountry_country_es' => 'Spain',
	'UserCountry_country_et' => 'Etiopia',
	'UserCountry_country_eu' => 'EU',
	'UserCountry_country_fi' => 'Finland',
	'UserCountry_country_fj' => 'Fiji',
	'UserCountry_country_fk' => 'Falklandsøyene',
	'UserCountry_country_fm' => 'Mikronesiaføderasjonen',
	'UserCountry_country_fo' => 'Færøyane',
	'UserCountry_country_fr' => 'Frankrike',
	'UserCountry_country_fx' => 'France, Metropolitan',
	'UserCountry_country_ga' => 'Gabon',
	'UserCountry_country_gb' => 'Storbritania',
	'UserCountry_country_gd' => 'Grenada',
	'UserCountry_country_ge' => 'Georgia',
	'UserCountry_country_gf' => 'Fransk Guyana',
	'UserCountry_country_gg' => 'Guernsey',
	'UserCountry_country_gh' => 'Ghana',
	'UserCountry_country_gi' => 'Gibraltar',
	'UserCountry_country_gl' => 'Grønland',
	'UserCountry_country_gm' => 'Gambia',
	'UserCountry_country_gn' => 'Guinea',
	'UserCountry_country_gp' => 'Guadeloupe',
	'UserCountry_country_gq' => 'Ekvatorial-Guinea',
	'UserCountry_country_gr' => 'Hellas',
	'UserCountry_country_gs' => 'South Georgia og South Sandwich øyane',
	'UserCountry_country_gt' => 'Guatemala',
	'UserCountry_country_gu' => 'Guam',
	'UserCountry_country_gw' => 'Guinea-Bissau',
	'UserCountry_country_gy' => 'Guyana',
	'UserCountry_country_hk' => 'Hong Kong',
	'UserCountry_country_hm' => 'Heard øya og McDonald øyane',
	'UserCountry_country_hn' => 'Honduras',
	'UserCountry_country_hr' => 'Kroatia',
	'UserCountry_country_ht' => 'Haiti',
	'UserCountry_country_hu' => 'Ungarn',
	'UserCountry_country_ic' => 'Kanariøyane',
	'UserCountry_country_id' => 'Indonesia',
	'UserCountry_country_ie' => 'Irland',
	'UserCountry_country_il' => 'Israel',
	'UserCountry_country_im' => 'øya Man',
	'UserCountry_country_in' => 'India',
	'UserCountry_country_io' => 'Det britiske imperiet',
	'UserCountry_country_iq' => 'Irak',
	'UserCountry_country_ir' => 'Iran, Den Islamske Republikk',
	'UserCountry_country_is' => 'Island',
	'UserCountry_country_it' => 'Italia',
	'UserCountry_country_je' => 'Jersey',
	'UserCountry_country_jm' => 'Jamaica',
	'UserCountry_country_jo' => 'Jordan',
	'UserCountry_country_jp' => 'Japan',
	'UserCountry_country_ke' => 'Kenya',
	'UserCountry_country_kg' => 'Kirgisistan',
	'UserCountry_country_kh' => 'Kambodsja',
	'UserCountry_country_ki' => 'Kiribati',
	'UserCountry_country_km' => 'Komorane',
	'UserCountry_country_kn' => 'Saint Kitts og Nevis',
	'UserCountry_country_kp' => 'Nord-Korea',
	'UserCountry_country_kr' => 'Sør-Korea',
	'UserCountry_country_kw' => 'Kuwait',
	'UserCountry_country_ky' => 'Cayman øane',
	'UserCountry_country_kz' => 'Kasakhstan',
	'UserCountry_country_la' => 'Laos',
	'UserCountry_country_lb' => 'Libanon',
	'UserCountry_country_lc' => 'Saint Lucia',
	'UserCountry_country_li' => 'Liechtenstein',
	'UserCountry_country_lk' => 'Sri Lanka',
	'UserCountry_country_lr' => 'Liberia',
	'UserCountry_country_ls' => 'Lesotho',
	'UserCountry_country_lt' => 'Litauen',
	'UserCountry_country_lu' => 'Luxembourg',
	'UserCountry_country_lv' => 'Latvia',
	'UserCountry_country_ly' => 'Libya',
	'UserCountry_country_ma' => 'Marokko',
	'UserCountry_country_mc' => 'Monaco',
	'UserCountry_country_md' => 'Moldova',
	'UserCountry_country_me' => 'Montenegro',
	'UserCountry_country_mf' => 'Saint Martin',
	'UserCountry_country_mg' => 'Madagaskar',
	'UserCountry_country_mh' => 'Marshall øyane',
	'UserCountry_country_mk' => 'Makedonia',
	'UserCountry_country_ml' => 'Mali',
	'UserCountry_country_mm' => 'Myanmar',
	'UserCountry_country_mn' => 'Mongolia',
	'UserCountry_country_mo' => 'Macao',
	'UserCountry_country_mp' => 'Nord-Marianane',
	'UserCountry_country_mq' => 'Martinique',
	'UserCountry_country_mr' => 'Mauritania',
	'UserCountry_country_ms' => 'Montserrat',
	'UserCountry_country_mt' => 'Malta',
	'UserCountry_country_mu' => 'Mauritius',
	'UserCountry_country_mv' => 'Maldivane',
	'UserCountry_country_mw' => 'Malawi',
	'UserCountry_country_mx' => 'Mexico',
	'UserCountry_country_my' => 'Malaysia',
	'UserCountry_country_mz' => 'Mosambik',
	'UserCountry_country_na' => 'Namibia',
	'UserCountry_country_nc' => 'New Caledonia',
	'UserCountry_country_ne' => 'Niger',
	'UserCountry_country_nf' => 'Norfolk Island',
	'UserCountry_country_ng' => 'Nigeria',
	'UserCountry_country_ni' => 'Nicaragua',
	'UserCountry_country_nl' => 'Nederland',
	'UserCountry_country_no' => 'Noreg',
	'UserCountry_country_np' => 'Nepal',
	'UserCountry_country_nr' => 'Nauru',
	'UserCountry_country_nt' => 'Nøytral sone',
	'UserCountry_country_nu' => 'Niue',
	'UserCountry_country_nz' => 'New Zealand',
	'UserCountry_country_om' => 'Oman',
	'UserCountry_country_pa' => 'Panama',
	'UserCountry_country_pe' => 'Peru',
	'UserCountry_country_pf' => 'Fransk Polynesia',
	'UserCountry_country_pg' => 'Papua New Guinea',
	'UserCountry_country_ph' => 'Filippinene',
	'UserCountry_country_pk' => 'Pakistan',
	'UserCountry_country_pl' => 'Polen',
	'UserCountry_country_pm' => 'Saint Pierre og Miquelon',
	'UserCountry_country_pn' => 'Pitcairn',
	'UserCountry_country_pr' => 'Puerto Rico',
	'UserCountry_country_ps' => 'Palestinsk område',
	'UserCountry_country_pt' => 'Portugal',
	'UserCountry_country_pw' => 'Palau',
	'UserCountry_country_py' => 'Paraguay',
	'UserCountry_country_qa' => 'Qatar',
	'UserCountry_country_re' => 'Reunion Island',
	'UserCountry_country_ro' => 'Romania',
	'UserCountry_country_rs' => 'Serbia',
	'UserCountry_country_ru' => 'Russland',
	'UserCountry_country_rw' => 'Rwanda',
	'UserCountry_country_sa' => 'Saudi Arabia',
	'UserCountry_country_sb' => 'Salomonøyane',
	'UserCountry_country_sc' => 'Seychellane',
	'UserCountry_country_sd' => 'Sudan',
	'UserCountry_country_se' => 'Sverige',
	'UserCountry_country_sf' => 'Finland',
	'UserCountry_country_sg' => 'Singapore',
	'UserCountry_country_sh' => 'Saint Helena',
	'UserCountry_country_si' => 'Slovenia',
	'UserCountry_country_sj' => 'Svalbard',
	'UserCountry_country_sk' => 'Slovakia',
	'UserCountry_country_sl' => 'Sierra Leone',
	'UserCountry_country_sm' => 'San Marino',
	'UserCountry_country_sn' => 'Senegal',
	'UserCountry_country_so' => 'Somalia',
	'UserCountry_country_sr' => 'Surinam',
	'UserCountry_country_st' => 'Sao Tome og Principe',
	'UserCountry_country_su' => 'gamle Soviet (U.S.S.R)',
	'UserCountry_country_sv' => 'El Salvador',
	'UserCountry_country_sy' => 'Syria',
	'UserCountry_country_sz' => 'Swaziland',
	'UserCountry_country_ta' => 'Tristan da Cunha',
	'UserCountry_country_tc' => 'Turks- og Caicosøyane',
	'UserCountry_country_td' => 'Tsjad',
	'UserCountry_country_tf' => 'French Southern Territories',
	'UserCountry_country_tg' => 'Togo',
	'UserCountry_country_th' => 'Thailand',
	'UserCountry_country_tj' => 'Tadsjikistan',
	'UserCountry_country_tk' => 'Tokelau',
	'UserCountry_country_tl' => 'Aust Timor',
	'UserCountry_country_tm' => 'Turkmenistan',
	'UserCountry_country_tn' => 'Tunisia',
	'UserCountry_country_to' => 'Tonga',
	'UserCountry_country_tp' => 'East Timor',
	'UserCountry_country_tr' => 'Tyrkia',
	'UserCountry_country_tt' => 'Trinidad and Tobago',
	'UserCountry_country_tv' => 'Tuvalu',
	'UserCountry_country_tw' => 'Taiwan',
	'UserCountry_country_tz' => 'Tanzania',
	'UserCountry_country_ua' => 'Ukraina',
	'UserCountry_country_ug' => 'Uganda',
	'UserCountry_country_uk' => 'Storbritania',
	'UserCountry_country_um' => 'USA Mindre Uteliggjande Øyar',
	'UserCountry_country_us' => 'USA',
	'UserCountry_country_uy' => 'Uruguay',
	'UserCountry_country_uz' => 'Usbekistan',
	'UserCountry_country_va' => 'Vatikanet',
	'UserCountry_country_vc' => 'Saint Vincent og Grenadinane',
	'UserCountry_country_ve' => 'Venezuela',
	'UserCountry_country_vg' => 'Dei britiske Jomfruøyane',
	'UserCountry_country_vi' => 'Dei amerikanske Jomfruøyane',
	'UserCountry_country_vn' => 'Vietnam',
	'UserCountry_country_vu' => 'Vanuatu',
	'UserCountry_country_wf' => 'Wallis og Futuna',
	'UserCountry_country_ws' => 'Samoa',
	'UserCountry_country_ye' => 'Yemen',
	'UserCountry_country_yt' => 'Mayotte',
	'UserCountry_country_yu' => 'Jugoslavia',
	'UserCountry_country_za' => 'Sørafrika',
	'UserCountry_country_zm' => 'Zambia',
	'UserCountry_country_zr' => 'Zaire',
	'UserCountry_country_zw' => 'Zimbabwe',
	'UserCountry_continent_eur' => 'Europa',
	'UserCountry_continent_afr' => 'Afrika',
	'UserCountry_continent_asi' => 'Asia',
	'UserCountry_continent_amn' => 'Nordamerika',
	'UserCountry_continent_ams' => 'Sør- og SentralAmerika',
	'UserCountry_continent_oce' => 'Oseania',
	'UserSettings_PluginDescription' => 'Rapporter diverse vitjarinnstillingar: Nettlesar, Nettlesarfamilie, operativsystem, oppløysing og globale innstillingar.',
	'UserSettings_VisitorSettings' => 'Vitjarinnstillingar',
	'UserSettings_BrowserFamilies' => 'Nettlesarfamiliar',
	'UserSettings_Browsers' => 'Nettlesarar',
	'UserSettings_Plugins' => 'Innstikk',
	'UserSettings_Configurations' => 'Konfigurasjonar',
	'UserSettings_OperatingSystems' => 'Operativsystem',
	'UserSettings_Resolutions' => 'Oppløysingar',
	'UserSettings_WideScreen' => 'Breiskjerm',
	'UserSettings_ColumnBrowserFamily' => 'Nettlesarfamilar',
	'UserSettings_ColumnBrowser' => 'Nettlesar',
	'UserSettings_ColumnPlugin' => 'Innstikk',
	'UserSettings_ColumnConfiguration' => 'Konfigurasjon',
	'UserSettings_ColumnOperatingSystem' => 'Operativsystem',
	'UserSettings_ColumnResolution' => 'Oppløysing',
	'UserSettings_ColumnTypeOfScreen' => 'Type skjerm',
	'UserSettings_WidgetResolutions' => 'Skjermoppløysing',
	'UserSettings_WidgetBrowsers' => 'Nytta nettlesarar',
	'UserSettings_WidgetPlugins' => 'Liste over innstikk',
	'UserSettings_PluginDetectionDoesNotWorkInIE' => 'Merk: Registrering av innstikk virkar ikkje i Internet Explorer. Denne rapporten er berre basert på andre nettlesarar enn IE.',
	'UserSettings_WidgetWidescreen' => 'Vanleg / Breiskjerm',
	'UserSettings_WidgetBrowserFamilies' => 'Nettlesarar etter familie',
	'UserSettings_WidgetOperatingSystems' => 'Operativsystem',
	'UserSettings_WidgetGlobalVisitors' => 'Global vitjarkonfigurasjon',
	'UserSettings_SubmenuSettings' => 'Innstillingar',
	'UsersManager_PluginDescription' => 'Piwiks brukarhehandling: Opprett ein ny brukar, endre ein eksisterande brukar eller oppdater tilgangar. Desse handlingane kan også nyttast gjennom APIet.',
	'UsersManager_UsersManagement' => 'Brukarbehandling',
	'UsersManager_UsersManagementMainDescription' => 'Lag nye brukarar eller oppdater eksisterande brukarar. Du kan deretter setta deira tilgangar ovanfor.',
	'UsersManager_ManageAccess' => 'Bestem tilgang',
	'UsersManager_MainDescription' => 'Bestem kven av brukarane som hev korleis tilgang til dine nettstader.    Du kan òg setja tilgang til alle nettstadene på ein gong.',
	'UsersManager_Sites' => 'Nettstader',
	'UsersManager_AllWebsites' => 'Alle nettstader',
	'UsersManager_ApplyToAllWebsites' => 'Gjer gjeldande for alle nettstader',
	'UsersManager_User' => 'Brukar',
	'UsersManager_PrivNone' => 'Inga tilgang',
	'UsersManager_PrivView' => 'Les',
	'UsersManager_PrivAdmin' => 'Administrator',
	'UsersManager_ChangeAllConfirm' => 'Er du sikker på at du vil endra \'%s\' tilgangar på alle nettstadene?',
	'UsersManager_Password' => 'Passord',
	'UsersManager_Email' => 'Epost',
	'UsersManager_Alias' => 'Alias',
	'UsersManager_TheSuperUserAliasCannotBeChanged' => 'Namnet på superbrukaren kan ikkje endrast.',
	'UsersManager_ExcludeVisitsViaCookie' => 'Utelukk dine vitjingar frå Piwik med ein informasjonskapsel.',
	'UsersManager_YourVisitsAreIgnoredOnDomain' => '%sDine vitjingar blir ignorert av Piwik på %s %s (Informasjonskapselen frå Piwik vart funnen i din nettlesar).',
	'UsersManager_YourVisitsAreNotIgnored' => '%sDine vitjingar blir ikkje ignorert av Piwik%s (Informasjonskapselen frå Piwik vart ikkje funnen i din nettlesar).',
	'UsersManager_ClickHereToDeleteTheCookie' => 'Klikk her for å sletta informasjonskapselen slik at Piwik loggar dine vitjingar',
	'UsersManager_Edit' => 'Endre',
	'UsersManager_AddUser' => 'Legg til ein ny brukar',
	'UsersManager_MenuUsers' => 'Brukarar',
	'UsersManager_MenuUserSettings' => 'Brukarinnstillingar',
	'UsersManager_MenuAnonymousUserSettings' => 'Innstillingar for anonyme brukarar',
	'UsersManager_NoteNoAnonymousUserAccessSettingsWontBeUsed' => 'Merk: Disse innstillingane blir ikkje brukt om du ikkje har nokon sider som er tilgjengelge for anonyme brukarar.',
	'UsersManager_WhenUsersAreNotLoggedInAndVisitPiwikTheyShouldAccess' => 'Når brukarar vitjar Piwik uten å vera innlogga, skal dei ha tilgang til',
	'UsersManager_ChangePassword' => 'Bytt passord',
	'UsersManager_IfYouWouldLikeToChangeThePasswordTypeANewOne' => 'Om du ønskjer å bytte passordet, skriv inn eit nytt et.    Ellers skriv du ingenting.',
	'UsersManager_TypeYourPasswordAgain' => 'Skriv ditt nye passord på nytt.',
	'UsersManager_TheLoginScreen' => 'Innloggingsskjermen',
	'UsersManager_DeleteConfirm_js' => 'Er du sikker på at du vil fjerna brukar %s?',
	'UsersManager_YourUsernameCannotBeChanged' => 'Brukarnamnet ditt kan ikkje endrast.',
	'UsersManager_ExceptionLoginExists' => 'Brukar \'%s\' finst allereie.',
	'UsersManager_ExceptionEmailExists' => 'Ein bukar med eposten \'%s\' finst allereie.',
	'UsersManager_ExceptionInvalidEmail' => 'Eposten hev eit ugyldig format.',
	'UsersManager_ExceptionDeleteDoesNotExist' => 'Brukaren \'%s\' kan ikkje slettast av di han ikkje finst.',
	'UsersManager_ExceptionAdminAnonymous' => 'Du kan ikkje gjeva administrasjonstilgang til den anonyme brukaren.',
	'UsersManager_ExceptionEditAnonymous' => 'Den anonyme brukaren kan ikkje bli endra eller sletta. Den er brukt av Piwik for å definera ein brukar som ikkje hev logga inn. Til døme kan du gjera statistikken offentleg tilgjengeleg ved å gjeva lesetilgang til den anonyme brukaren.',
	'UsersManager_ExceptionSuperUser' => 'Den valde brukaren er superbrukaren, og kan ikkje bli henta, endra eller redigert via APIet. Du kan endre han manuelt i Piwik sin konfigurasjonsfil.',
	'UsersManager_ExceptionUserDoesNotExist' => 'Brukar \'%s\' finst ikkje.',
	'UsersManager_ExceptionAccessValues' => 'Parameteren tilgang må ha ein av dei følgjande verdiane :    [ %s ]',
	'UsersManager_ExceptionPasswordMD5HashExpected' => 'UsersManager.getTokenAuth forventar eit MD5-hasja passord (ein 32 teikn lang streng). Nytt md5()-funksjonen på passord før du kallar denne metoden.',
	'VisitFrequency_Evolution' => 'Utvikling gjennom perioden',
	'VisitFrequency_ColumnReturningVisits' => 'Tilbakevendande Vitjarar',
	'VisitFrequency_ColumnActionsByReturningVisits' => 'Handlingar av Tilbakevendande Vitjarar',
	'VisitFrequency_ColumnBounceRateForReturningVisits' => 'Hopprate for Tilbakevendande Vitjarar',
	'VisitFrequency_ColumnAvgActionsPerReturningVisit' => 'Gjen. handlingar per tilbakevendande vitjing',
	'VisitFrequency_ReturnVisits' => '%s tilbakevendande vitjingar',
	'VisitFrequency_ReturnActions' => '%s handlingar frå dei tilbakevendande vitjarane',
	'VisitFrequency_ReturnAvgActions' => '%s handlingar per tilbakevendande vitjing',
	'VisitFrequency_ReturnBounceRate' => '%s tilbakevendande vitjarar hev hoppa (forsvunne frå nettstaden etter ei sidevising)',
	'VisitFrequency_WidgetOverview' => 'Frekvensoversikt',
	'VisitFrequency_WidgetGraphReturning' => 'Graf tilbakevendande vitjarar',
	'VisitFrequency_SubmenuFrequency' => 'Frekvens',
	'VisitorGenerator_AreYouSure' => 'Er du sikker på at du vil generera falske vitjingar?',
	'VisitorGenerator_ChoiceYes' => 'Ja, eg er sikker!',
	'VisitorGenerator_SelectWebsite' => 'Vel nettstad',
	'VisitorInterest_VisitsPerDuration' => 'Vitjingar per vitjingstid',
	'VisitorInterest_VisitsPerNbOfPages' => 'Vitjingar per mengd sider',
	'VisitorInterest_ColumnVisitDuration' => 'Vitjingslengde',
	'VisitorInterest_ColumnPagesPerVisit' => 'Sider per vitjing',
	'VisitorInterest_WidgetLengths' => 'Lengda på vitjingane',
	'VisitorInterest_WidgetPages' => 'Sider per vitjing',
	'VisitorInterest_Engagement' => 'Engasjement',
	'VisitorInterest_PlusXMin' => '%s min',
	'VisitorInterest_OnePage' => '1 side',
	'VisitorInterest_NPages' => '%s sider',
	'VisitsSummary_NbVisits' => '%s vitjingar',
	'VisitsSummary_NbUniqueVisitors' => '%s unike vitjarar',
	'VisitsSummary_MaxNbActions' => '%s maks mengd handlingar på ein vitjing',
	'VisitsSummary_NbVisitsBounced' => '%s vitjarar hev hoppa (forsvunne etter ein sidevising)',
	'VisitsSummary_EvolutionOverLastPeriods' => 'Utvikling over den siste %s',
	'VisitsSummary_GenerateTime' => '%s sekundar å generera denne siden',
	'VisitsSummary_GenerateQueries' => '%s spørjingar køyrd',
	'VisitsSummary_WidgetLastVisits' => 'Siste vitjingar',
	'VisitsSummary_WidgetVisits' => 'Vitjingsoversikt',
	'VisitsSummary_WidgetLastVisitors' => 'Graf over dei siste unike vitjarane',
	'VisitsSummary_WidgetOverviewGraph' => 'Oversikt med graf',
	'VisitsSummary_SubmenuOverview' => 'Oversikt',
	'VisitTime_LocalTime' => 'Vitjingar per brukartid',
	'VisitTime_ServerTime' => 'Vitjingar per tenartid',
	'VisitTime_ColumnServerTime' => 'Tenartid',
	'VisitTime_ColumnLocalTime' => 'Brukartid',
	'VisitTime_WidgetLocalTime' => 'Vitjingar etter brukartid',
	'VisitTime_WidgetServerTime' => 'Vitjingar etter tenartid',
	'VisitTime_SubmenuTimes' => 'Tid',
	'VisitTime_NHour' => '%st',
);
